@@ -1,31 +1,38 @@
-/* Libvoikko: Finnish spellchecker and hyphenator library
- * Copyright (C) 2010 Harri Pitkänen <hatapitk@iki.fi>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+/* The contents of this file are subject to the Mozilla Public License Version 
+ * 1.1 (the "License"); you may not use this file except in compliance with 
+ * the License. You may obtain a copy of the License at 
+ * http://www.mozilla.org/MPL/
+ * 
+ * Software distributed under the License is distributed on an "AS IS" basis,
+ * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
+ * for the specific language governing rights and limitations under the
+ * License.
+ * 
+ * The Original Code is Libvoikko: Library of natural language processing tools.
+ * The Initial Developer of the Original Code is Harri Pitkänen <hatapitk@iki.fi>.
+ * Portions created by the Initial Developer are Copyright (C) 2010 - 2012
+ * the Initial Developer. All Rights Reserved.
+ * 
+ * Alternatively, the contents of this file may be used under the terms of
+ * either the GNU General Public License Version 2 or later (the "GPL"), or
+ * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
+ * in which case the provisions of the GPL or the LGPL are applicable instead
+ * of those above. If you wish to allow use of your version of this file only
+ * under the terms of either the GPL or the LGPL, and not to allow others to
+ * use your version of this file under the terms of the MPL, indicate your
+ * decision by deleting the provisions above and replace them with the notice
+ * and other provisions required by the GPL or the LGPL. If you do not delete
+ * the provisions above, a recipient may use your version of this file under
+ * the terms of any one of the MPL, the GPL or the LGPL.
  *********************************************************************************/
 
 package org.puimula.libvoikko;
 
 import com.sun.jna.Library;
-import com.sun.jna.NativeLong;
 import com.sun.jna.Pointer;
 import com.sun.jna.PointerType;
-import com.sun.jna.ptr.NativeLongByReference;
 import com.sun.jna.ptr.PointerByReference;
 
-// XXX: NativeLong is used to represent size_t. This may not work everywhere (64 bit Windows?)
 interface Libvoikko extends Library {
 
     public static final int VOIKKO_SPELL_FAILED = 0;
@@ -62,15 +69,15 @@ interface Libvoikko extends Library {
     public abstract void voikkoFreeCstrArray(Pointer array);
     
     public abstract VoikkoGrammarError voikkoNextGrammarErrorCstr(VoikkoHandle handle, byte[] text,
-            NativeLong textLen, NativeLong startPos, int skipErrors);
+            SizeT textLen, SizeT startPos, int skipErrors);
 
     public abstract void voikkoFreeGrammarError(VoikkoGrammarError error);
     
     public abstract int voikkoGetGrammarErrorCode(VoikkoGrammarError error);
     
-    public abstract NativeLong voikkoGetGrammarErrorStartPos(VoikkoGrammarError error);
+    public abstract SizeT voikkoGetGrammarErrorStartPos(VoikkoGrammarError error);
     
-    public abstract NativeLong voikkoGetGrammarErrorLength(VoikkoGrammarError error);
+    public abstract SizeT voikkoGetGrammarErrorLength(VoikkoGrammarError error);
     
     public abstract Pointer voikkoGetGrammarErrorSuggestions(VoikkoGrammarError error);
     
@@ -86,11 +93,11 @@ interface Libvoikko extends Library {
     
     public abstract void voikko_free_mor_analysis_value_cstr(ByteArray analysisValue);
     
-    public abstract int voikkoNextTokenCstr(VoikkoHandle handle, byte[] text, NativeLong textLen,
-            NativeLongByReference tokenLen);
+    public abstract int voikkoNextTokenCstr(VoikkoHandle handle, byte[] text, SizeT textLen,
+            SizeTByReference tokenLen);
     
-    public abstract int voikkoNextSentenceStartCstr(VoikkoHandle handle, byte[] text, NativeLong textLen,
-            NativeLongByReference sentenceLen);
+    public abstract int voikkoNextSentenceStartCstr(VoikkoHandle handle, byte[] text, SizeT textLen,
+            SizeTByReference sentenceLen);
 
     public abstract ByteArray voikkoHyphenateCstr(VoikkoHandle handle, byte[] word);
     
