@@ -1,19 +1,29 @@
-/* Libvoikko: Finnish spellchecker and hyphenator library
- * Copyright (C) 2008 - 2011 Harri Pitkänen <hatapitk@iki.fi>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+/* The contents of this file are subject to the Mozilla Public License Version 
+ * 1.1 (the "License"); you may not use this file except in compliance with 
+ * the License. You may obtain a copy of the License at 
+ * http://www.mozilla.org/MPL/
+ * 
+ * Software distributed under the License is distributed on an "AS IS" basis,
+ * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
+ * for the specific language governing rights and limitations under the
+ * License.
+ * 
+ * The Original Code is Libvoikko: Library of natural language processing tools.
+ * The Initial Developer of the Original Code is Harri Pitkänen <hatapitk@iki.fi>.
+ * Portions created by the Initial Developer are Copyright (C) 2008 - 2011
+ * the Initial Developer. All Rights Reserved.
+ * 
+ * Alternatively, the contents of this file may be used under the terms of
+ * either the GNU General Public License Version 2 or later (the "GPL"), or
+ * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
+ * in which case the provisions of the GPL or the LGPL are applicable instead
+ * of those above. If you wish to allow use of your version of this file only
+ * under the terms of either the GPL or the LGPL, and not to allow others to
+ * use your version of this file under the terms of the MPL, indicate your
+ * decision by deleting the provisions above and replace them with the notice
+ * and other provisions required by the GPL or the LGPL. If you do not delete
+ * the provisions above, a recipient may use your version of this file under
+ * the terms of any one of the MPL, the GPL or the LGPL.
  *********************************************************************************/
 
 #include "grammar/analysis.hpp"
@@ -37,6 +47,8 @@ static void gc_analyze_token(voikko_options_t * voikkoOptions, Token * token) {
 	token->isGeographicalNameInGenitive = false;
 	token->possibleGeographicalName = false;
 	token->possibleMainVerb = false;
+	token->possibleConjunction = false;
+	token->isMainVerb = true;
 	token->isVerbNegative = false;
 	token->isPositiveVerb = true;
 	token->isConjunction = true;
@@ -77,17 +89,23 @@ static void gc_analyze_token(voikko_options_t * voikkoOptions, Token * token) {
 				token->isGeographicalNameInGenitive = true;
 			}
 		}
-		if (!wclass || wcscmp(L"sidesana", wclass) != 0) {
+		
+		if (wclass && wcscmp(L"sidesana", wclass) == 0) {
+			token->possibleConjunction = true;
+		}
+		else {
 			token->isConjunction = false;
 		}
 		
 		if (!wclass) {
 			token->isPositiveVerb = false;
 			token->possibleMainVerb = true;
+			token->isMainVerb = false;
 		}
 		else if (wcscmp(L"kieltosana", wclass) == 0) {
 			token->isVerbNegative = true;
 			token->isPositiveVerb = false;
+			token->isMainVerb = false;
 		}
 		else if (wcscmp(L"teonsana", wclass) == 0) {
 			if (!negative || wcscmp(L"false", negative) != 0 ||
@@ -98,9 +116,13 @@ static void gc_analyze_token(voikko_options_t * voikkoOptions, Token * token) {
 			    (!negative || wcscmp(L"true", negative) != 0)) {
 				token->possibleMainVerb = true;
 			}
+			if (!mood || wcscmp(L"indicative", mood) != 0) {
+				token->isMainVerb = false;
+			}
 		}
 		else {
 			token->isPositiveVerb = false;
+			token->isMainVerb = false;
 		}
 		
 		if (possibleGeographicalName && wcscmp(L"true", possibleGeographicalName) == 0) {
@@ -146,6 +168,7 @@ static void gc_analyze_token(voikko_options_t * voikkoOptions, Token * token) {
 	if (!token->isValidWord) {
 		token->isPositiveVerb = false;
 		token->isConjunction = false;
+		token->isMainVerb = false;
 	}
 }
 
@@ -181,8 +204,7 @@ static Sentence * gc_analyze_sentence(voikko_options_t * voikkoOptions,
 			next_word_is_possible_sentence_start = false;
 		}
 		else if (tt == TOKEN_PUNCTUATION &&
-		         ((tokenlen == 1 &&
-		           (tstr[0] == L'.' || tstr[0] == L':' || tstr[0] == L'\u2026'))
+		         ((tokenlen == 1 && wcschr(L".:\u2026\u2013\u2014", tstr[0]) != 0)
 		          || tokenlen == 3)) { // . : ... may separate sentences
 			next_word_is_possible_sentence_start = true;
 		}
